==> iobroker.go-e-1.0.23.tgz: package/admin/words.js <==
/*global systemDictionary:true */
"use strict";

systemDictionary = {
    "go-echarger adapter settings": {
        "en": "Adapter settings for go-echarger",
        "de": "Adaptereinstellungen für go-echarger",
        "ru": "Настройки адаптера для go-echarger",
        "pt": "Configurações do adaptador para go-echarger",
        "nl": "Adapterinstellingen voor go-echarger",
        "fr": "Paramètres d'adaptateur pour go-echarger",
        "it": "Impostazioni dell'adattatore per go-echarger",
        "es": "Ajustes del adaptador para go-echarger",
        "pl": "Ustawienia adaptera dla go-echarger",
        "zh-cn": "go-echarger的适配器设置"
    },
    "serverName": {
        "en": "Server Name or ip address like &quot;192.168.1.100&quot; or &quot;go-eCharger.domain.local&quot;",
        "de": "Server Name oder IP Adresse wie Bsp: &quot;192.168.1.100&quot; oder &quot;go-eCharger.fritz.box&quot;",
        "ru": "Имя сервера или IP-адрес, например \"192.168.1.100\" или & quot; go-eCharger.domain.local & quot;",
        "pt": "Nome do servidor ou endereço IP como & quot; 192.168.1.100 & quot; ou & quot; go-eCharger.domain.local & quot;",
        "nl": "Servernaam of ip-adres zoals '192.168.1.100' of & quot; go-eCharger.domain.local & quot;",
        "fr": "Nom du serveur ou adresse IP comme & quot; 192.168.1.100 & quot; ou & quot; go-eCharger.domain.local & quot;",
        "it": "Nome server o indirizzo IP come & quot; 192.168.1.100 & quot; o & quot; go-eCharger.domain.local & quot;",
        "es": "Nombre del servidor o dirección IP como & quot; 192.168.1.100 & quot; o & quot; go-eCharger.domain.local & quot;",
        "pl": "Nazwa serwera lub adres IP, na przykład „192.168.1.100” lub „go-eCharger.domain.local”",
        "zh-cn": "服务器名称或IP地址（例如“ 192.168.1.100”）或“ go-eCharger.domain.local”"
    },
    "serverInterval": {
        "en": "Refresh Interval",
        "de": "Aktualisierungsintervall",
        "ru": "Интервал обновления",
        "pt": "Intervalo de atualização",
        "nl": "Vernieuwingsinterval",
        "fr": "Intervalle de rafraîchissement",
        "it": "Intervallo di aggiornamento",
        "es": "Intervalo de actualización",
        "pl": "Częstotliwość odświeżania",
        "zh-cn": "刷新间隔"
    },
    "ampUpdateInterval": {
        "en": "Max. Interval for writing updates to the hardware in seconds (Reduce below 30 seconds at your own risk! The adapter could be damaged.) ",
        "de": "max. Intervall zum Schreiben von Updates auf die Hardware in Sekunden (Reduzierung unter 30 Sekunden auf eigene Gefahr! Der Adapter könnte beschädigt werden.)",
        "ru": "Максимум. Интервал записи обновлений на оборудование в секундах (сокращайте время до 30 секунд на свой страх и риск! Адаптер может быть поврежден).",
        "pt": "Máx. Intervalo para gravar atualizações no hardware em segundos (reduza para menos de 30 segundos por sua própria conta e risco! O adaptador pode ser danificado).",
        "nl": "Maximaal Interval voor het schrijven van updates naar de hardware in seconden (Verkort minder dan 30 seconden op eigen risico! De adapter kan beschadigd raken.)",
        "fr": "Max. Intervalle d'écriture des mises à jour sur le matériel en secondes (réduisez en dessous de 30 secondes à vos risques et périls ! L'adaptateur pourrait être endommagé.)",
        "it": "massimo Intervallo per la scrittura degli aggiornamenti sull'hardware in secondi (ridurre al di sotto di 30 secondi a proprio rischio! L'adattatore potrebbe essere danneggiato.)",
        "es": "Max. Intervalo para escribir actualizaciones en el hardware en segundos (¡Reduzca a menos de 30 segundos bajo su propio riesgo! El adaptador podría dañarse).",
        "pl": "Maks. Odstęp czasu na zapisywanie aktualizacji sprzętu w sekundach (skróć poniżej 30 sekund na własne ryzyko! Adapter może zostać uszkodzony.)",
        "zh-cn": "最大限度。以秒为单位向硬件写入更新的间隔（将其减少到 30 秒以下，风险自负！适配器可能会损坏。）"
    },
    "sentryEnabled": {
        "en": "send debugging messages to Sentry as help for developers",
        "de": "Senden von Debugging-Nachrichten an Sentry als Hilfe für Entwickler",
        "ru": "отправлять отладочные сообщения в Sentry в качестве помощи для разработчиков",
        "pt": "enviar mensagens de depuração para Sentry como ajuda para desenvolvedores",
        "nl": "stuur foutopsporingsberichten naar Sentry als hulp voor ontwikkelaars",
        "fr": "envoyer des messages de débogage à Sentry comme aide pour les développeurs",
        "it": "inviare messaggi di debug a Sentry come aiuto per gli sviluppatori",
        "es": "enviar mensajes de depuración a Sentry como ayuda para los desarrolladores",
        "pl": "wysyłaj wiadomości debugowania do Sentry jako pomoc dla programistów",
        "zh-cn": "向 Sentry 发送调试消息作为开发人员的帮助"
    },
    "solarPowerForeignObjectID": {
        "en": "object-id for currently available solar power in watts [W]",
        "de": "ObjektID für die aktuell verfügbare Solarleistung in Watt [W]",
        "ru": "идентификатор объекта для доступной в настоящее время солнечной энергии в ваттах [Вт]",
        "pt": "object-id para energia solar atualmente disponível em watts [W]",
        "nl": "object-id voor momenteel beschikbare zonne-energie in watt [W]",
        "fr": "object-id pour l'énergie solaire actuellement disponible en watts [W]",
        "it": "ID oggetto per l'energia solare attualmente disponibile in watt [W]",
        "es": "ID de objeto para la energía solar disponible actualmente en vatios [W]",
        "pl": "object-id dla aktualnie dostępnej energii słonecznej w watach [W]",
        "zh-cn": "以瓦特为单位的当前可用太阳能的对象 ID [W]"
    },
    "houseConsumptionForeignObjectID": {
        "en": "object-id for current home power consumption in watts [W]",
        "de": "ObjektID für den aktuellen Stromverbrauch zu Hause in Watt [W]",
        "ru": "идентификатор объекта для текущего потребления электроэнергии дома в ваттах [Вт]",
        "pt": "object-id para o consumo atual de energia doméstica em watts [W]",
        "nl": "object-id voor huidig stroomverbruik thuis in watt [W]",
        "fr": "object-id pour la consommation électrique domestique actuelle en watts [W]",
        "it": "ID oggetto per il consumo energetico domestico corrente in watt [W]",
        "es": "ID de objeto para el consumo actual de energía en el hogar en vatios [W]",
        "pl": "object-id dla aktualnego zużycia energii w domu w watach [W]",
        "zh-cn": "以瓦特为单位的当前家庭功耗的对象 ID [W]"
    },
    "houseBatteryForeignObjectID": {
        "en": "object-id for current home battery state of charge in watt hours [Wh]",
        "de": "Objekt-ID für aktuellen Ladezustand der Heimbatterie in Wattstunden [Wh]",
        "ru": "идентификатор объекта для текущего уровня заряда домашнего аккумулятора в ватт-часах [Вт-ч]",
        "pt": "object-id para o estado atual de carga da bateria doméstica em watt-hora [Wh]",
        "nl": "object-id voor de huidige oplaadstatus van de thuisbatterij in wattuur [Wh]",
        "fr": "object-id pour l'état de charge actuel de la batterie domestique en wattheures [Wh]",
        "it": "id oggetto per lo stato di carica attuale della batteria domestica in wattora [Wh]",
        "es": "ID de objeto para el estado de carga actual de la batería doméstica en vatios hora [Wh]",
        "pl": "Object-id dla aktualnego stanu naładowania akumulatora domowego w watogodzinach [Wh]",
        "zh-cn": "以瓦特小时为单位的当前家用电池充电状态的对象 ID [Wh]"
    },
    "bufferToSolar": {
        "en": "Buffer to the outcome from solar panel to the usage of loading process",
        "de": "Puffer zwischen Solarpanel-Ertrag und der Nutzung für den Ladevorgang in Watt [W]",
        "ru": "Буфер результата от солнечной панели к использованию процесса загрузки",
        "pt": "Buffer para o resultado do painel solar para o uso do processo de carregamento",
        "nl": "Buffer voor de uitkomst van het zonnepaneel tot het gebruik van het laadproces",
        "fr": "Tampon au résultat du panneau solaire à l'utilisation du processus de chargement",
        "it": "Buffer per il risultato dal pannello solare all'utilizzo del processo di caricamento",
        "es": "Amortiguador del resultado del panel solar al uso del proceso de carga",
        "pl": "Bufor do wyniku z panelu słonecznego do wykorzystania procesu ładowania",
        "zh-cn": "缓冲太阳能电池板的结果到加载过程的使用"
    },
    "bufferToBattery": {
        "en": "minimum battery level in watt hours [Wh]",
        "de": "Minimum Akkustand in Wattstunden [Wh]",
        "ru": "Установите минимальный уровень заряда батареи в ватт-час [Wh]",
        "pt": "Buffeer para o nível mínimo de bateria em watt-hora [Wh]",
        "nl": "Buffer tot het minimum Batterijniveau in wattuur [Wh]",
        "fr": "Buffer au minimum Niveau de batterie en wattheure [Wh]",
        "it": "Buffer al minimo Livello batteria in wattora [Wh]",
        "es": "Buffeer al nivel mínimo de batería en vatios hora [Wh]",
        "pl": "Bufor do minimum Poziom naładowania baterii w watogodzinach [Wh]",
        "zh-cn": "以瓦特小时为单位缓冲到最低电池电量 [Wh]"
    },
    "writeTemperatureArray": {
        "en": "Write temperature Array",
        "de": "Schreibe das Temperatur Array",
        "ru": "Write temperature Array",
        "pt": "Write temperature Array",
        "nl": "Write temperature Array",
        "fr": "Write temperature Array",
        "it": "Write temperature Array",
        "es": "Write temperature Array",
        "pl": "Write temperature Array",
        "zh-cn": "Write temperature Array"
    },
    "onlyAck": {
        "en": "Ack?",
        "de": "Ack?"
    }
};

==> iobroker.go-e-1.0.29.tgz: package/admin/words.js <==
/*global systemDictionary:true */
"use strict";

systemDictionary = {
    "go-echarger adapter settings": {
        "en": "Adapter settings for go-echarger",
        "de": "Adaptereinstellungen für go-echarger",
        "ru": "Настройки адаптера для go-echarger",
        "pt": "Configurações do adaptador para go-echarger",
        "nl": "Adapterinstellingen voor go-echarger",
        "fr": "Paramètres d'adaptateur pour go-echarger",
        "it": "Impostazioni dell'adattatore per go-echarger",
        "es": "Ajustes del adaptador para go-echarger",
        "pl": "Ustawienia adaptera dla go-echarger",
        "zh-cn": "go-echarger的适配器设置"
    },
    "serverName": {
        "en": "Server Name or ip address like &quot;192.168.1.100&quot; or &quot;go-eCharger.domain.local&quot;",
        "de": "Server Name oder IP Adresse wie Bsp: &quot;192.168.1.100&quot; oder &quot;go-eCharger.fritz.box&quot;",
        "ru": "Имя сервера или IP-адрес, например \"192.168.1.100\" или & quot; go-eCharger.domain.local & quot;",
        "pt": "Nome do servidor ou endereço IP como & quot; 192.168.1.100 & quot; ou & quot; go-eCharger.domain.local & quot;",
        "nl": "Servernaam of ip-adres zoals '192.168.1.100' of & quot; go-eCharger.domain.local & quot;",
        "fr": "Nom du serveur ou adresse IP comme & quot; 192.168.1.100 & quot; ou & quot; go-eCharger.domain.local & quot;",
        "it": "Nome server o indirizzo IP come & quot; 192.168.1.100 & quot; o & quot; go-eCharger.domain.local & quot;",
        "es": "Nombre del servidor o dirección IP como & quot; 192.168.1.100 & quot; o & quot; go-eCharger.domain.local & quot;",
        "pl": "Nazwa serwera lub adres IP, na przykład „192.168.1.100” lub „go-eCharger.domain.local”",
        "zh-cn": "服务器名称或IP地址（例如“ 192.168.1.100”）或“ go-eCharger.domain.local”"
    },
    "serverInterval": {
        "en": "Refresh Interval",
        "de": "Aktualisierungsintervall",
        "ru": "Интервал обновления",
        "pt": "Intervalo de atualização",
        "nl": "Vernieuwingsinterval",
        "fr": "Intervalle de rafraîchissement",
        "it": "Intervallo di aggiornamento",
        "es": "Intervalo de actualización",
        "pl": "Częstotliwość odświeżania",
        "zh-cn": "刷新间隔"
    },
    "ampUpdateInterval": {
        "en": "Max. Interval for writing updates to the hardware in seconds (Reduce below 30 seconds at your own risk! The adapter could be damaged.) ",
        "de": "max. Intervall zum Schreiben von Updates auf die Hardware in Sekunden (Reduzierung unter 30 Sekunden auf eigene Gefahr! Der Adapter könnte beschädigt werden.)",
        "ru": "Максимум. Интервал записи обновлений на оборудование в секундах (сокращайте время до 30 секунд на свой страх и риск! Адаптер может быть поврежден).",
        "pt": "Máx. Intervalo para gravar atualizações no hardware em segundos (reduza para menos de 30 segundos por sua própria conta e risco! O adaptador pode ser danificado).",
        "nl": "Maximaal Interval voor het schrijven van updates naar de hardware in seconden (Verkort minder dan 30 seconden op eigen risico! De adapter kan beschadigd raken.)",
        "fr": "Max. Intervalle d'écriture des mises à jour sur le matériel en secondes (réduisez en dessous de 30 secondes à vos risques et périls ! L'adaptateur pourrait être endommagé.)",
        "it": "massimo Intervallo per la scrittura degli aggiornamenti sull'hardware in secondi (ridurre al di sotto di 30 secondi a proprio rischio! L'adattatore potrebbe essere danneggiato.)",
        "es": "Max. Intervalo para escribir actualizaciones en el hardware en segundos (¡Reduzca a menos de 30 segundos bajo su propio riesgo! El adaptador podría dañarse).",
        "pl": "Maks. Odstęp czasu na zapisywanie aktualizacji sprzętu w sekundach (skróć poniżej 30 sekund na własne ryzyko! Adapter może zostać uszkodzony.)",
        "zh-cn": "最大限度。以秒为单位向硬件写入更新的间隔（将其减少到 30 秒以下，风险自负！适配器可能会损坏。）"
    },
    "sentryEnabled": {
        "en": "send debugging messages to Sentry as help for developers",
        "de": "Senden von Debugging-Nachrichten an Sentry als Hilfe für Entwickler",
        "ru": "отправлять отладочные сообщения в Sentry в качестве помощи для разработчиков",
        "pt": "enviar mensagens de depuração para Sentry como ajuda para desenvolvedores",
        "nl": "stuur foutopsporingsberichten naar Sentry als hulp voor ontwikkelaars",
        "fr": "envoyer des messages de débogage à Sentry comme aide pour les développeurs",
        "it": "inviare messaggi di debug a Sentry come aiuto per gli sviluppatori",
        "es": "enviar mensajes de depuración a Sentry como ayuda para los desarrolladores",
        "pl": "wysyłaj wiadomości debugowania do Sentry jako pomoc dla programistów",
        "zh-cn": "向 Sentry 发送调试消息作为开发人员的帮助"
    },
    "solarPowerForeignObjectID": {
        "en": "object-id for currently available solar power in watts [W]",
        "de": "ObjektID für die aktuell verfügbare Solarleistung in Watt [W]",
        "ru": "идентификатор объекта для доступной в настоящее время солнечной энергии в ваттах [Вт]",
        "pt": "object-id para energia solar atualmente disponível em watts [W]",
        "nl": "object-id voor momenteel beschikbare zonne-energie in watt [W]",
        "fr": "object-id pour l'énergie solaire actuellement disponible en watts [W]",
        "it": "ID oggetto per l'energia solare attualmente disponibile in watt [W]",
        "es": "ID de objeto para la energía solar disponible actualmente en vatios [W]",
        "pl": "object-id dla aktualnie dostępnej energii słonecznej w watach [W]",
        "zh-cn": "以瓦特为单位的当前可用太阳能的对象 ID [W]"
    },
    "houseConsumptionForeignObjectID": {
        "en": "object-id for current home power consumption in watts [W]",
        "de": "ObjektID für den aktuellen Stromverbrauch zu Hause in Watt [W]",
        "ru": "идентификатор объекта для текущего потребления электроэнергии дома в ваттах [Вт]",
        "pt": "object-id para o consumo atual de energia doméstica em watts [W]",
        "nl": "object-id voor huidig stroomverbruik thuis in watt [W]",
        "fr": "object-id pour la consommation électrique domestique actuelle en watts [W]",
        "it": "ID oggetto per il consumo energetico domestico corrente in watt [W]",
        "es": "ID de objeto para el consumo actual de energía en el hogar en vatios [W]",
        "pl": "object-id dla aktualnego zużycia energii w domu w watach [W]",
        "zh-cn": "以瓦特为单位的当前家庭功耗的对象 ID [W]"
    },
    "houseBatteryForeignObjectID": {
        "en": "object-id for current powerflow of battery in watts hours [W]",
        "de": "Objekt-ID für den aktuellen Stromfluss der Heimbatterie in Watt [W]"

    }, "bufferToSolar": {
        "en": "Buffer to the outcome from solar panel to the usage of loading process",
        "de": "Puffer zwischen Solarpanel-Ertrag und der Nutzung für den Ladevorgang in Watt [W]",
        "ru": "Буфер результата от солнечной панели к использованию процесса загрузки",
        "pt": "Buffer para o resultado do painel solar para o uso do processo de carregamento",
        "nl": "Buffer voor de uitkomst van het zonnepaneel tot het gebruik van het laadproces",
        "fr": "Tampon au résultat du panneau solaire à l'utilisation du processus de chargement",
        "it": "Buffer per il risultato dal pannello solare all'utilizzo del processo di caricamento",
        "es": "Amortiguador del resultado del panel solar al uso del proceso de carga",
        "pl": "Bufor do wyniku z panelu słonecznego do wykorzystania procesu ładowania",
        "zh-cn": "缓冲太阳能电池板的结果到加载过程的使用"
    },
    "bufferToBattery": {
        "en": "minimum battery level in watt hours [Wh]",
        "de": "Minimum Akkustand in Wattstunden [Wh]",
        "ru": "Установите минимальный уровень заряда батареи в ватт-час [Wh]",
        "pt": "Buffeer para o nível mínimo de bateria em watt-hora [Wh]",
        "nl": "Buffer tot het minimum Batterijniveau in wattuur [Wh]",
        "fr": "Buffer au minimum Niveau de batterie en wattheure [Wh]",
        "it": "Buffer al minimo Livello batteria in wattora [Wh]",
        "es": "Buffeer al nivel mínimo de batería en vatios hora [Wh]",
        "pl": "Bufor do minimum Poziom naładowania baterii w watogodzinach [Wh]",
        "zh-cn": "以瓦特小时为单位缓冲到最低电池电量 [Wh]"
    },
    "writeTemperatureArray": {
        "en": "Write temperature Array",
        "de": "Schreibe das Temperatur Array",
        "ru": "Write temperature Array",
        "pt": "Write temperature Array",
        "nl": "Write temperature Array",
        "fr": "Write temperature Array",
        "it": "Write temperature Array",
        "es": "Write temperature Array",
        "pl": "Write temperature Array",
        "zh-cn": "Write temperature Array"
    },
    "solarPowerForeignObjectAck": {
        "en": "Ack?",
        "de": "Ack?"
    },
    "houseBatteryForeignObjectAck": {
        "en": "Ack?",
        "de": "Ack?"
    },
    "houseConsumptionForeignObjectAck": {
        "en": "Ack?",
        "de": "Ack?"
    },
    "solarPowerForeignObjectNegate": {
        "en": "Negate?",
        "de": "negieren?"
    },
    "houseBatteryForeignObjectNegate": {
        "en": "Negate?",
        "de": "negieren?"
    },
    "apiVersion": {
        "en": "If you have Hardware in Version 2 you need API-Version 1. If you installed Hardware Version 3 or later you can activate API V2 in the go-eCharger - App.",
        "de": "Wenn du HW V2 besitzt, muss du die Einstellung bei API V1 belassen. Ab HW Version 3 kann auch die API V2 alternativ aktivieren."
    },
    "loadWith6AAtLeast": {
        "en": "Load with at least 6A:<br />Behavior when enabled if not enougth pv power is available: 3Phases => 1Phase => continue with 1P & 6Amperes",
        "de": "Laden mit min 6A:<br />Verhalten bei aktiviert: 3Phasen => 1Phase => min. 1P & 6Ampere; Bei deaktiviert: 3Phasen => 1Phase => Stopp;"
    }
};
